@@ -40,7 +40,7 @@ import msgparsing
 from diff import seddiff
 
 
-VERSION = '1.15'
+VERSION = '1.16'
 
 
 class IrcDisconnectError(Exception): ...
@@ -104,7 +104,7 @@ class Client:
     def __init__(
                     self,
                     s: asyncio.streams.StreamWriter,
-                    sl_client: Union[slack.Slack],
+                    sl_client: slack.Slack,
                     settings: ClientSettings,
 
     ):
@@ -112,16 +112,16 @@ class Client:
         self.username = b''
         self.realname = b''
         self.parted_channels: Set[bytes] = settings.ignored_channels
-        self.known_threads: Dict[bytes, slack.MessageThread] = {}
+        self.known_threads: dict[bytes, slack.MessageThread] = {}
         self.hostname = gethostname().encode('utf8')
 
         self.settings = settings
         self.s = s
         self.sl_client = sl_client
         self._usersent = False # Used to hold all events until the IRC client sends the initial USER message
-        self._held_events: List[slack.SlackEvent] = []
-        self._mentions_regex_cache: Dict[str, Optional[re.Pattern]] = {}  # Cache for the regexp to perform mentions. Key is channel id
-        self._annoy_users: Dict[str, int] = {} # Users to annoy pretending to type when they type
+        self._held_events: list[slack.SlackEvent] = []
+        self._mentions_regex_cache: dict[str, Optional[re.Pattern]] = {}  # Cache for the regexp to perform mentions. Key is channel id
+        self._annoy_users: dict[str, int] = {} # Users to annoy pretending to type when they type
 
     async def _nickhandler(self, cmd: bytes) -> None:
         if b' ' not in cmd:
@@ -133,7 +133,7 @@ class Client:
         if self.nick != self.sl_client.login_info.self.name.encode('ascii'):
             await self._sendreply(Replies.ERR_ERRONEUSNICKNAME, 'Incorrect nickname, use %s' % self.sl_client.login_info.self.name)
 
-    async def _sendreply(self, code: Union[int,Replies], message: Union[str,bytes], extratokens: Iterable[Union[str,bytes]] = []) -> None:
+    async def _sendreply(self, code: int|Replies, message: str|bytes, extratokens: Iterable[str|bytes] = []) -> None:
         codeint = code if isinstance(code, int) else code.value
         bytemsg = message if isinstance(message, bytes) else message.encode('utf8')
 
@@ -157,6 +157,7 @@ class Client:
         await self._sendreply(2, 'Your team name is: %s' % self.sl_client.login_info.team.name)
         await self._sendreply(2, 'Your team domain is: %s' % self.sl_client.login_info.team.domain)
         await self._sendreply(2, 'Your nickname must be: %s' % self.sl_client.login_info.self.name)
+        await self._sendreply(2, f'Version: {VERSION}')
         await self._sendreply(Replies.RPL_LUSERCLIENT, 'There are 1 users and 0 services on 1 server')
 
         if self.settings.autojoin and not self.settings.nouserlist:
@@ -220,11 +221,11 @@ class Client:
         except Exception:
             await self._sendreply(Replies.ERR_NOSUCHCHANNEL, f'Unable to join channel: {channel_name}')
 
-    async def _send_chan_info(self, channel_name: bytes, slchan: Union[slack.Channel, slack.MessageThread]):
+    async def _send_chan_info(self, channel_name: bytes, slchan: slack.Channel|slack.MessageThread):
         if not self.settings.nouserlist:
             l = await self.sl_client.get_members(slchan.id)
 
-            userlist: List[bytes] = []
+            userlist: list[bytes] = []
             for i in l:
                 try:
                     u = await self.sl_client.get_user(i)
@@ -238,8 +239,12 @@ class Client:
                 userlist.append(prefix + name)
 
             users = b' '.join(userlist)
+        try:
+            yelldest = b'#' + (await self.sl_client.get_channel(slchan.id)).name.encode('utf8')
+        except KeyError:
+            yelldest = b''
 
-        topic = (await self.parse_message(slchan.real_topic, b'')).replace('\n', ' | ')
+        topic = (await self.parse_message(slchan.real_topic, b'', yelldest)).replace('\n', ' | ')
         self.s.write(b':%s!%s@127.0.0.1 JOIN %s\r\n' % (self.nick, self.nick, channel_name))
         await self.s.drain()
         await self._sendreply(Replies.RPL_TOPIC, topic, [channel_name])
@@ -261,7 +266,7 @@ class Client:
             action = False
 
         if dest in self.known_threads:
-            dest_object: Union[slack.User, slack.Channel, slack.MessageThread] = self.known_threads[dest]
+            dest_object: slack.User|slack.Channel|slack.MessageThread = self.known_threads[dest]
         elif dest.startswith(b'#'):
             try:
                 dest_object = await self.sl_client.get_channel_by_name(dest[1:].decode())
@@ -292,7 +297,7 @@ class Client:
 
     async def _listhandler(self, cmd: bytes) -> None:
         for c in await self.sl_client.channels(refresh=True):
-            topic = (await self.parse_message(c.real_topic, b'')).replace('\n', ' | ')
+            topic = (await self.parse_message(c.real_topic, b'', b'')).replace('\n', ' | ')
             await self._sendreply(Replies.RPL_LIST, topic, ['#' + c.name, str(c.num_members)])
         await self._sendreply(Replies.RPL_LISTEND, 'End of LIST')
 
@@ -509,7 +514,7 @@ class Client:
         ))
         await self.s.drain()
 
-    async def _get_regexp(self, dest: Union[slack.User, slack.Channel]) -> Optional[re.Pattern]:
+    async def _get_regexp(self, dest: slack.User|slack.Channel) -> Optional[re.Pattern]:
         #del self._mentions_regex_cache[sl_ev.channel]
         # No nick substitutions for private chats
         if isinstance(dest, slack.User):
@@ -536,7 +541,7 @@ class Client:
         self._mentions_regex_cache[dest_id] = regex
         return regex
 
-    async def _addmagic(self, msg: str, dest: Union[slack.User, slack.Channel]) -> str:
+    async def _addmagic(self, msg: str, dest: slack.User|slack.Channel) -> str:
         """
         Adds magic codes and various things to
         outgoing messages
@@ -562,7 +567,7 @@ class Client:
                 msg = msg[0:m.start()] + '<@%s>' % (await self.sl_client.get_user_by_name(username)).id + msg[m.end():]
         return msg
 
-    async def parse_message(self, i: str, source: bytes) -> str:
+    async def parse_message(self, i: str, source: bytes, destination: bytes) -> str:
         """
         This converts a slack message into a message for IRC.
 
@@ -604,7 +609,10 @@ class Client:
                 elif t.kind == msgparsing.Itemkind.CHANNEL: # Channel mention
                     r += '#' + (await self.sl_client.get_channel(t.val)).name_normalized
                 elif t.kind == msgparsing.Itemkind.YELL: # Channel shouting
-                    yell = ' [%s]:' % self.nick.decode('utf8') if source not in self.settings.silenced_yellers else ':'
+                    if (source not in self.settings.silenced_yellers) and (destination not in self.settings.silenced_yellers):
+                         yell = ' [%s]:' % self.nick.decode('utf8')
+                    else:
+                        yell = ':'
                     if t.val == 'here':
                         r += 'yelling' + yell
                     elif t.val == 'channel':
@@ -627,9 +635,13 @@ class Client:
     async def _messageedit(self, sl_ev: slack.MessageEdit) -> None:
         if not sl_ev.is_changed:
             return
+        try:
+            yelldest = b'#' + (await self.sl_client.get_channel(sl_ev.channel)).name.encode('utf8')
+        except KeyError:
+            yelldest = b''
         source = (await self.sl_client.get_user(sl_ev.previous.user)).name.encode('utf8')
-        previous = await self.parse_message(sl_ev.previous.text, source)
-        current = await self.parse_message(sl_ev.current.text, source)
+        previous = await self.parse_message(sl_ev.previous.text, source, yelldest)
+        current = await self.parse_message(sl_ev.current.text, source, yelldest)
 
         diffmsg = slack.Message(
             text=seddiff(sl_ev.previous.text, sl_ev.current.text),
@@ -640,7 +652,7 @@ class Client:
 
         await self._message(diffmsg)
 
-    async def _message(self, sl_ev: Union[slack.Message, slack.MessageDelete, slack.MessageBot, slack.ActionMessage], prefix: str='') -> None:
+    async def _message(self, sl_ev: slack.Message|slack.MessageDelete|slack.MessageBot|slack.ActionMessage, prefix: str=''):
         """
         Sends a message to the irc client
         """
@@ -650,9 +662,10 @@ class Client:
             source = b'bot'
 
         try:
-            dest = b'#' + (await self.sl_client.get_channel(sl_ev.channel)).name.encode('utf8')
+            yelldest = dest = b'#' + (await self.sl_client.get_channel(sl_ev.channel)).name.encode('utf8')
         except KeyError:
             dest = self.nick
+            yelldest = b''
         except Exception as e:
             log('Error: ', str(e))
             return
@@ -678,7 +691,7 @@ class Client:
             for f in sl_ev.files:
                 text+=f'\n[file upload] {f.name}\n{f.mimetype} {f.size} bytes\n{f.url_private}'
 
-        lines = (await self.parse_message(prefix + text, source)).encode('utf-8')
+        lines = (await self.parse_message(prefix + text, source, yelldest)).encode('utf-8')
         for i in lines.split(b'\n'):
             if not i:
                 continue
@@ -690,7 +703,7 @@ class Client:
                 i
             )
 
-    async def _joined_parted(self, sl_ev: Union[slack.Join, slack.Leave], joined: bool) -> None:
+    async def _joined_parted(self, sl_ev: slack.Join|slack.Leave, joined: bool) -> None:
         """
         Handle join events from slack, by sending a JOIN notification
         to IRC.
@@ -1002,7 +1015,7 @@ async def from_irc(reader, ircclient: Client):
             raise IrcDisconnectError()
         await ircclient.command(cmd.strip())
 
-async def to_irc(sl_client: Union[slack.Slack], ircclient: Client):
+async def to_irc(sl_client: slack.Slack, ircclient: Client):
     while True:
         ev = await sl_client.event()
         if ev:
